History of Dead-Hosts
---------------------

The project started on 3rd March 2017 at `funilrys/dead-hosts`_.

The original idea was to test `Funceble`_ against hosts file in order
to find bugs inside `Funceble`_ but also letting me (@funilrys) have a shorter 
hosts file.

On 23rd January 2018, I (@funilrys) decided to shut `funilrys/dead-hosts`_ 
down, as it became impossible to test all members of the project without having 
to wait for weeks. I then decided it was time to move on to another level.

That was the beginning of `Dead-Hosts`_.

Today `Dead-Hosts`_'s is objective to provide project and lists to maintainers 
or individuals, with the help of PyFunceble, to provide more information about 
their favourite project/list or domains, IP or URL.

.. _funilrys/dead-hosts: https://github.com/funilrys/dead-hosts
.. _Funceble: https://github.com/funilrys/funceble
.. _Dead-Hosts: https://github.com/dead-hosts
